import { ConnectionOptions, HassServices, HassConfig, MessageBase, HassEntity } from "./types";
declare type EventListener = (conn: Connection, eventData?: any) => void;
declare type Events = "ready" | "disconnected" | "reconnect-error";
export declare class Connection {
    options: ConnectionOptions;
    commandId: number;
    commands: {
        [commandId: number]: any;
    };
    eventListeners: {
        [eventType: string]: EventListener[];
    };
    closeRequested: boolean;
    socket: WebSocket;
    constructor(socket: WebSocket, options: ConnectionOptions);
    setSocket(socket: WebSocket): void;
    addEventListener(eventType: Events, callback: EventListener): void;
    removeEventListener(eventType: Events, callback: EventListener): void;
    fireEvent(eventType: Events, eventData?: any): void;
    close(): void;
    getStates(): Promise<HassEntity[]>;
    getServices(): Promise<HassServices>;
    getConfig(): Promise<HassConfig>;
    callService(domain: string, service: string, serviceData?: object): Promise<{}>;
    subscribeEvents<EventType>(eventCallback: (ev: EventType) => void, eventType: string): Promise<() => Promise<void>>;
    ping(): Promise<{}>;
    sendMessage(message: MessageBase, commandId?: number): void;
    sendMessagePromise<Result>(message: MessageBase, commandId?: number): Promise<Result>;
    private _handleMessage;
    private _handleClose;
    private _genCmdId;
}
export default function createConnection(options?: Partial<ConnectionOptions>): Promise<Connection>;
export {};
